@@ -66,7 +66,7 @@ fn test_expr_qmark() {
 fn test_expr_template() {
     let template_dir = "tests/data/templates";
     let out = cargo_script!(
-        #[env(CARGO_SCRIPT_DEBUG_TEMPLATE_PATH=template_dir)]
+        #[env(RUST_SCRIPT_DEBUG_TEMPLATE_PATH=template_dir)]
         "-t",
         "shout",
         "-e",
@@ -83,7 +83,7 @@ fn test_expr_template() {
 fn test_expr_template_with_deps() {
     let template_dir = "tests/data/templates";
     let out = cargo_script!(
-        #[env(CARGO_SCRIPT_DEBUG_TEMPLATE_PATH=template_dir)]
+        #[env(RUST_SCRIPT_DEBUG_TEMPLATE_PATH=template_dir)]
         "-t",
         "boolinate",
         "-e",
@@ -100,7 +100,7 @@ fn test_expr_template_with_deps() {
 fn test_expr_template_override_expr() {
     let template_dir = "tests/data/templates/override";
     let out = cargo_script!(
-        #[env(CARGO_SCRIPT_DEBUG_TEMPLATE_PATH=template_dir)]
+        #[env(RUST_SCRIPT_DEBUG_TEMPLATE_PATH=template_dir)]
         "-e",
         with_output_marker!(r#"true"#)
     )
