@@ -4,5 +4,6 @@ fn test_version() {
     assert!(out.success());
     scan!(&out.stdout;
         ("rust-script", &::std::env::var("CARGO_PKG_VERSION").unwrap(), .._) => ()
-    ).unwrap();
+    )
+    .unwrap();
 }
