@@ -6,12 +6,12 @@ macro_rules! cargo_script {
         $($args:expr),* $(,)*
     ) => {
         {
-            extern crate tempdir;
+            extern crate tempfile;
             use std::process::Command;
 
-            let cargo_lock = ::util::CARGO_MUTEX.lock().expect("Could not acquire Cargo mutex");
+            let cargo_lock = crate::util::CARGO_MUTEX.lock().expect("Could not acquire Cargo mutex");
 
-            let temp_dir = tempdir::TempDir::new("rust-script-test").unwrap();
+            let temp_dir = tempfile::TempDir::new().unwrap();
             let cmd_str;
             let out = {
                 let target_dir = ::std::env::var("CARGO_TARGET_DIR")
@@ -28,7 +28,7 @@ macro_rules! cargo_script {
                 cmd_str = format!("{:?}", cmd);
 
                 cmd.output()
-                    .map(::util::Output::from)
+                    .map(crate::util::Output::from)
             };
 
             if let Ok(out) = out.as_ref() {
@@ -57,11 +57,11 @@ macro_rules! cargo_script {
 
 macro_rules! with_output_marker {
     (prelude $p:expr; $e:expr) => {
-        format!(concat!($p, "{}", $e), ::util::OUTPUT_MARKER_CODE)
+        format!(concat!($p, "{}", $e), crate::util::OUTPUT_MARKER_CODE)
     };
 
     ($e:expr) => {
-        format!(concat!("{}", $e), ::util::OUTPUT_MARKER_CODE)
+        format!(concat!("{}", $e), crate::util::OUTPUT_MARKER_CODE)
     };
 }
 
@@ -70,8 +70,8 @@ lazy_static! {
     pub static ref CARGO_MUTEX: Mutex<()> = Mutex::new(());
 }
 
-pub const OUTPUT_MARKER: &'static str = "--output--";
-pub const OUTPUT_MARKER_CODE: &'static str = "println!(\"--output--\");";
+pub const OUTPUT_MARKER: &str = "--output--";
+pub const OUTPUT_MARKER_CODE: &str = "println!(\"--output--\");";
 
 pub struct Output {
     pub status: ::std::process::ExitStatus,
@@ -83,25 +83,21 @@ impl Output {
     pub fn stdout_output(&self) -> &str {
         assert!(self.success());
         for marker in self.stdout.matches(OUTPUT_MARKER) {
-            let i = subslice_offset(&self.stdout, marker)
-                .expect("couldn't find marker in output");
-            let before_cp = self.stdout[..i].chars().rev().next()
-                .unwrap_or('\n');
-            if !(before_cp == '\r' || before_cp == '\n') { continue; }
-            let after = &self.stdout[i+OUTPUT_MARKER.len()..];
-            let after_cp = after.chars().next()
-                .expect("couldn't find cp after marker");
-            if !(after_cp == '\r' || after_cp == '\n') { continue; }
+            let i = subslice_offset(&self.stdout, marker).expect("couldn't find marker in output");
+            let before_cp = self.stdout[..i].chars().rev().next().unwrap_or('\n');
+            if !(before_cp == '\r' || before_cp == '\n') {
+                continue;
+            }
+            let after = &self.stdout[i + OUTPUT_MARKER.len()..];
+            let after_cp = after.chars().next().expect("couldn't find cp after marker");
+            if !(after_cp == '\r' || after_cp == '\n') {
+                continue;
+            }
             return after;
         }
         panic!("could not find `{}` in script output", OUTPUT_MARKER);
     }
 
-    pub fn stderr_raw(&self) -> &str {
-        assert!(self.success());
-        &self.stderr[..]
-    }
-
     pub fn success(&self) -> bool {
         self.status.success()
     }
@@ -109,7 +105,7 @@ impl Output {
 
 impl From<::std::process::Output> for Output {
     fn from(v: ::std::process::Output) -> Self {
-        Output {
+        Self {
             status: v.status,
             stdout: String::from_utf8(v.stdout).unwrap(),
             stderr: String::from_utf8(v.stderr).unwrap(),
